/*
 * LCD_5110_SPI_main
 * Demóprogram a Nokia 5110 LCD kipróbálásához (hardveres SPI támogatással)
 * 
 * Szerző: Rei VILO, Jan 12, 2013
 *
 * Hardver követelmények:
 *  - Launchpad kártya MSP430G2553 mikrovezérlővel
 *  - Nokia 5110 LCD kijelző
 *
 * Huzalozási vázlat:
 *
 * Nokia 5110(Sparkfun)       MSP430      
 * ---------------------------------
 * 1. VCC     tápfeszültség    VCC  
 * 2. GND     közös pont       GND   
 * 3. SCE     kiválasztó jel   P2.2 
 * 4. RST     RESET            P1.0 
 * 5. D/C     adat/parancs     P2.3  
 * 6. DIN     MOSI adatvonal   P1.7 
 * 7. SCLK    SPI órajel       P1.5 
 * 8. LED     háttérvilágítás  P2.1
 *
 * Nokia 5110 (E-bay)         MSP430      
 * ---------------------------------
 * 1. RST     RESET            P1.0 
 * 2. CE      kiválasztó jel   P2.2 
 * 3. DC      adat/parancs     P2.3  
 * 4. DIN     MOSI adatvonal   P1.7 
 * 5. CLK     SPI órajel       P1.5 
 * 6. VCC     tápfeszültség    VCC  
 * 7. LIGHT   háttérvilágítás  P2.1 (0: on, 1: off)
 * 8. GND     közös pont       GND  
 */

#include "Energia.h"
#include "SPI.h"
#include "LCD_5110_SPI.h"

LCD_5110_SPI myScreen;
boolean	backlight = false; 
uint8_t k = 0;

void setup() {
    SPI.begin();
    SPI.setClockDivider(SPI_CLOCK_DIV4);
    SPI.setBitOrder(MSBFIRST);
    SPI.setDataMode(SPI_MODE0);   
    
    myScreen.begin();                      //LCD inicializálás
    myScreen.setBacklight(backlight);      //Háttérvilágítás bekapcsolása
    myScreen.text(0, 0, "LCD 5110 test");  //Kiírás kis karakterekkel  
    myScreen.text(0, 5, "Light off");
    myScreen.setFont(1);                   //Nagy font választása
    myScreen.text(0, 2, " MSP430");        //Kiírás nagy fonttal 
    myScreen.setFont(0);                   //Kis font kiválasztás
}

void loop() {
    if (myScreen.getButton()) {            //A nyomógomb ki-be kapcsolja a világítást
        backlight = (backlight==0);
        myScreen.text(0, 5, backlight ? "Light on " : "Light off");
        myScreen.setBacklight(backlight);
    }
    for (uint8_t i=0; i<14; i++) myScreen.text(i, 4, (i==k) ? "*" : " ");
    k ++;
    k %= 14;    
    delay(200);
}
