/*
 * LCD_5110_thermometer
 * Hőmérséklet mérése MCP9700A analóg szenzorral,
 * Nokia 5110 LCD kijelzéssel (hardveres SPI támogatással)
 *
 * Hardver követelmények:
 *  - Launchpad kártya MSP430G2553 mikrovezérlővel
 *  - Nokia 5110 LCD kijelző
 *  - MCP9700A analóg hőmérő
 *
 * Huzalozási vázlat:
 *
 * MCP9700A 1: VCC, 2: P1.4, 3: GND)
 *
 * Nokia 5110(Sparkfun)       MSP430      
 * ---------------------------------
 * 1. VCC     tápfeszültség    VCC  
 * 2. GND     közös pont       GND   
 * 3. SCE     kiválasztó jel   P2.2 
 * 4. RST     RESET            P1.0 
 * 5. D/C     adat/parancs     P2.3  
 * 6. DIN     MOSI adatvonal   P1.7 
 * 7. SCLK    SPI órajel       P1.5 
 * 8. LED     háttérvilágítás  P2.1
 *
 * Nokia 5110 (E-bay)         MSP430      
 * ---------------------------------
 * 1. RST     RESET            P1.0 
 * 2. CE      kiválasztó jel   P2.2 
 * 3. DC      adat/parancs     P2.3  
 * 4. DIN     MOSI adatvonal   P1.7 
 * 5. CLK     SPI órajel       P1.5 
 * 6. VCC     tápfeszültség    VCC  
 * 7. LIGHT   háttérvilágítás  P2.1 (0: on, 1: off)
 * 8. GND     közös pont       GND  
 */

#include "Energia.h"
#include "SPI.h"
#include "LCD_5110_SPI.h"

LCD_5110_SPI myScreen;
boolean	backlight = false; 
char temp[8] = {' ', ' ', ' ', '.', ' ', 0x7f, 'C', 0x00};

void setup() {
    SPI.begin();
    SPI.setClockDivider(SPI_CLOCK_DIV4);
    SPI.setBitOrder(MSBFIRST);
    SPI.setDataMode(SPI_MODE0);   
    analogReference(INTERNAL1V5);    
    myScreen.begin();                      //LCD inicializálás
    myScreen.setBacklight(backlight);      //Háttérvilágítás bekapcsolása
    myScreen.text(0, 0, " Thermometer ");  //Kiírás kis karakterekkel  
    myScreen.text(0, 5, "Light off");
}

void loop() {
    if (myScreen.getButton()) {            //A nyomógomb ki-be kapcsolja a világítást
        backlight = (backlight==0);
        myScreen.setFont(0); 
        myScreen.text(0, 5, backlight ? "Light on " : "Light off");
        myScreen.setBacklight(backlight);
    }
    long mysum = 0;
    for(int i=0; i<12000; i++) {
       mysum += analogRead(A4);
    }
    long t = (mysum>>13)-500;          //a hőmérséklet tizedfokokban 
    displayData(t,temp);               //karakterekké konvertálás
    myScreen.setFont(1);
    myScreen.text(0, 2, temp);
    delay(200);
}

//Tizedfokokban mért hőmérséklet kiírásához 
//a kiírandó karaktersorozat előállítása
//Negatív értékek kezelésére nincs felkészítve!
void displayData(long data, char *buffer) {
    buffer[4] = 0x30 + data%10;        //tizedesjegy
    data /= 10;
    buffer[2] = 0x30 + data%10;        //egyesek
    data /= 10;
    if(data) {
        buffer[1] = 0x30 + data%10;    //tízesek
        data /= 10;
    } else { buffer[1] = ' '; }
     if(data) {
        buffer[0] = 0x30 + data%10;    //százasok
        data /= 10;
    } else { buffer[0] = ' '; }  
} 
